/* global Stripe, stripe_checkout_params */

window.onload = function () {
	const cardElement = document.getElementById( 'stripe-card-element' );
	if ( ! cardElement ) {
		return;
	}

	const stripe = Stripe( stripe_checkout_params.key );
	const elements = stripe.elements( {
		locale: stripe_checkout_params.locale,
	} );

	// Custom styling can be passed to options when creating an Element.
	const style = {
		base: {
			color: '#32325d',
			fontFamily: '"Helvetica Neue", Helvetica, sans-serif',
			fontSmoothing: 'antialiased',
			fontSize: '16px',
			'::placeholder': {
				color: '#aab7c4',
			},
		},
		invalid: {
			color: '#fa755a',
			iconColor: '#fa755a',
		},
	};

	// Create an instance of the card Element.
	const card = elements.create( 'card', { style } );

	card.mount( '#stripe-card-element' );

	// Handle real-time validation errors from the card Element.
	card.addEventListener( 'change', function ( event ) {
		const displayError = document.getElementById( 'stripe-card-errors' );
		if ( event.error ) {
			displayError.textContent = event.error.message;
		} else {
			displayError.textContent = '';
		}
	} );

	// Handle form submission.
	let paymentIncluded = false;
	const form = document.getElementById( 'stripe-checkout-form' );
	const cardholderName = document.getElementById( 'stripe-cardholder-name' );
	form.addEventListener( 'submit', function ( event ) {
		if ( paymentIncluded ) {
			return true;
		}
		event.preventDefault();

		const displayError = document.getElementById( 'stripe-card-errors' );
		const spinner = this.querySelector( '.spinner' );
		const buttons = this.querySelectorAll( 'input[type=submit]' );
		buttons.forEach( function ( button ) {
			button.classList.add( 'disabled' );
			button.addEventListener( 'click', function ( buttonClickEvent ) {
				if ( button.classList.contains( 'disabled' ) ) {
					buttonClickEvent.preventDefault();

					return false;
				}

				return true;
			} );
		} );

		spinner.classList.add( 'is-active' );

		displayError.textContent = '';

		const clientSecret = form.dataset.secret;
		stripe
			.handleCardPayment( clientSecret, card, {
				payment_method_data: {
					billing_details: {
						name: cardholderName.value,
					},
				},
			} )
			.then( function ( result ) {
				if ( result.error ) {
					spinner.classList.remove( 'is-active' );
					buttons.forEach( function ( button ) {
						button.classList.remove( 'disabled' );
					} );

					// Display error.message in your UI.
					displayError.textContent = result.error.message;
				} else if (
					result.paymentIntent &&
					result.paymentIntent.status === 'succeeded'
				) {
					paymentIncluded = true;

					// Submit the form.
					form.submit();
				} else {
					displayError.textContent =
						stripe_checkout_params.unknown_error_message;
				}
			} );
	} );
};
